@@ -959,6 +959,9 @@ class RunsAPI:
         fields: Optional[List[RunField]] = None,
     ) -> ApiResponse[PaginatedResponseRunResponse]:
         """List runs with optional filtering.
+        
+        Runs are ordered by: RUNNING (by started_at DESC) first, then all others (by ended_at DESC).
+        This surfaces active work and recent completions.
 
         Args:
             skip: Pagination skip
@@ -971,7 +974,14 @@ class RunsAPI:
             created_at_to: Optional end datetime (UTC or ISO string)
             fields: Optional list of fields to include per run (projection). When set,
                 the response includes only these plus base fields (id, workflow_id,
-                machine_id, status, created_at).
+                machine_id, status, created_at). Available fields include: started_at,
+                ended_at, error, output_data, input_values, and more.
+        
+        Returns:
+            ApiResponse with RunResponse objects including timing fields:
+                - created_at: When run was created
+                - started_at: When run execution started (null for SCHEDULING runs)
+                - ended_at: When run completed (null for RUNNING/SCHEDULING runs)
         """
         try:
             response = await list_runs_v1_runs_get.asyncio(
@@ -1109,7 +1119,14 @@ class RunsAPI:
             return ApiResponse(error=e)
     
     async def get(self, run_id: str) -> ApiResponse[RunResponse]:
-        """Get a specific run by ID."""
+        """Get a specific run by ID.
+        
+        Returns:
+            ApiResponse with RunResponse including timing information:
+                - created_at: When run was created
+                - started_at: When run execution started (null if not started)
+                - ended_at: When run completed (null if not finished)
+        """
         try:
             response = await get_run_v1_runs_run_id_get.asyncio(
                 client=self.client,
@@ -1120,7 +1137,14 @@ class RunsAPI:
             return ApiResponse(error=e)
     
     def get_sync(self, run_id: str) -> ApiResponse[RunResponse]:
-        """Get a specific run by ID (synchronous)."""
+        """Get a specific run by ID (synchronous).
+        
+        Returns:
+            ApiResponse with RunResponse including timing information:
+                - created_at: When run was created
+                - started_at: When run execution started (null if not started)
+                - ended_at: When run completed (null if not finished)
+        """
         try:
             response = get_run_v1_runs_run_id_get.sync(
                 client=self.client,
