@@ -1,5 +1,6 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union, cast
+from io import BytesIO
+from typing import Any, Optional, Union
 from uuid import UUID
 
 import httpx
@@ -7,7 +8,7 @@ import httpx
 from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.http_validation_error import HTTPValidationError
-from ...types import Response
+from ...types import File, Response
 
 
 def _get_kwargs(
@@ -23,9 +24,10 @@ def _get_kwargs(
 
 def _parse_response(
     *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[Any, HTTPValidationError]]:
+) -> Optional[Union[File, HTTPValidationError]]:
     if response.status_code == 200:
-        response_200 = cast(Any, None)
+        response_200 = File(payload=BytesIO(response.content))
+
         return response_200
 
     if response.status_code == 422:
@@ -41,7 +43,7 @@ def _parse_response(
 
 def _build_response(
     *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[Any, HTTPValidationError]]:
+) -> Response[Union[File, HTTPValidationError]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -54,7 +56,7 @@ def sync_detailed(
     attachment_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[Any, HTTPValidationError]]:
+) -> Response[Union[File, HTTPValidationError]]:
     """Download Run Attachment
 
      Download a run attachment file.
@@ -69,7 +71,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[Any, HTTPValidationError]]
+        Response[Union[File, HTTPValidationError]]
     """
 
     kwargs = _get_kwargs(
@@ -87,7 +89,7 @@ def sync(
     attachment_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[Any, HTTPValidationError]]:
+) -> Optional[Union[File, HTTPValidationError]]:
     """Download Run Attachment
 
      Download a run attachment file.
@@ -102,7 +104,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[Any, HTTPValidationError]
+        Union[File, HTTPValidationError]
     """
 
     return sync_detailed(
@@ -115,7 +117,7 @@ async def asyncio_detailed(
     attachment_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[Any, HTTPValidationError]]:
+) -> Response[Union[File, HTTPValidationError]]:
     """Download Run Attachment
 
      Download a run attachment file.
@@ -130,7 +132,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[Any, HTTPValidationError]]
+        Response[Union[File, HTTPValidationError]]
     """
 
     kwargs = _get_kwargs(
@@ -146,7 +148,7 @@ async def asyncio(
     attachment_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[Any, HTTPValidationError]]:
+) -> Optional[Union[File, HTTPValidationError]]:
     """Download Run Attachment
 
      Download a run attachment file.
@@ -161,7 +163,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[Any, HTTPValidationError]
+        Union[File, HTTPValidationError]
     """
 
     return (
