@@ -2,6 +2,7 @@ from enum import Enum
 
 
 class RunField(str, Enum):
+    ENDED_AT = "ended_at"
     ERROR = "error"
     INPUT_ATTACHMENT_IDS = "input_attachment_ids"
     INPUT_VALUES = "input_values"
@@ -15,6 +16,7 @@ class RunField(str, Enum):
     SENSITIVE_INPUT_ALIASES = "sensitive_input_aliases"
     SESSION_ALIAS = "session_alias"
     SESSION_ID = "session_id"
+    STARTED_AT = "started_at"
     USER_ID = "user_id"
 
     def __str__(self) -> str:
