@@ -43,6 +43,8 @@ class RunResponse:
         session_id (Union[None, UUID, Unset]):
         session_alias (Union[None, Unset, str]):
         release_session_after (Union[None, Unset, bool]):
+        started_at (Union[None, Unset, datetime.datetime]):
+        ended_at (Union[None, Unset, datetime.datetime]):
     """
 
     workflow_id: UUID
@@ -63,6 +65,8 @@ class RunResponse:
     session_id: Union[None, UUID, Unset] = UNSET
     session_alias: Union[None, Unset, str] = UNSET
     release_session_after: Union[None, Unset, bool] = UNSET
+    started_at: Union[None, Unset, datetime.datetime] = UNSET
+    ended_at: Union[None, Unset, datetime.datetime] = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -193,6 +197,22 @@ class RunResponse:
         else:
             release_session_after = self.release_session_after
 
+        started_at: Union[None, Unset, str]
+        if isinstance(self.started_at, Unset):
+            started_at = UNSET
+        elif isinstance(self.started_at, datetime.datetime):
+            started_at = self.started_at.isoformat()
+        else:
+            started_at = self.started_at
+
+        ended_at: Union[None, Unset, str]
+        if isinstance(self.ended_at, Unset):
+            ended_at = UNSET
+        elif isinstance(self.ended_at, datetime.datetime):
+            ended_at = self.ended_at.isoformat()
+        else:
+            ended_at = self.ended_at
+
         field_dict: dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -230,6 +250,10 @@ class RunResponse:
             field_dict["session_alias"] = session_alias
         if release_session_after is not UNSET:
             field_dict["release_session_after"] = release_session_after
+        if started_at is not UNSET:
+            field_dict["started_at"] = started_at
+        if ended_at is not UNSET:
+            field_dict["ended_at"] = ended_at
 
         return field_dict
 
@@ -475,6 +499,40 @@ class RunResponse:
 
         release_session_after = _parse_release_session_after(d.pop("release_session_after", UNSET))
 
+        def _parse_started_at(data: object) -> Union[None, Unset, datetime.datetime]:
+            if data is None:
+                return data
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, str):
+                    raise TypeError()
+                started_at_type_0 = isoparse(data)
+
+                return started_at_type_0
+            except:  # noqa: E722
+                pass
+            return cast(Union[None, Unset, datetime.datetime], data)
+
+        started_at = _parse_started_at(d.pop("started_at", UNSET))
+
+        def _parse_ended_at(data: object) -> Union[None, Unset, datetime.datetime]:
+            if data is None:
+                return data
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, str):
+                    raise TypeError()
+                ended_at_type_0 = isoparse(data)
+
+                return ended_at_type_0
+            except:  # noqa: E722
+                pass
+            return cast(Union[None, Unset, datetime.datetime], data)
+
+        ended_at = _parse_ended_at(d.pop("ended_at", UNSET))
+
         run_response = cls(
             workflow_id=workflow_id,
             machine_id=machine_id,
@@ -494,6 +552,8 @@ class RunResponse:
             session_id=session_id,
             session_alias=session_alias,
             release_session_after=release_session_after,
+            started_at=started_at,
+            ended_at=ended_at,
         )
 
         run_response.additional_properties = d
